==> haskell-hslogger-1.2.10-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hslogger.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hslogger
version: 1.2.10
id: hslogger-1.2.10-P9bS995VPJKC7x0yPUAEo
key: hslogger-1.2.10-P9bS995VPJKC7x0yPUAEo
license: BSD3
copyright: Copyright (c) 2004-2012 John Goerzen
maintainer: John Goerzen <jgoerzen@complete.org>
stability: Stable
homepage: http://software.complete.org/hslogger
synopsis: Versatile logging framework
description:
    hslogger is a logging framework for Haskell, roughly similar to
    Python'\''s logging module.
    .
    hslogger lets each log message have a priority and source be associated
    with it.  The programmer can then define global handlers that route
    or filter messages based on the priority and source.  hslogger also
    has a syslog handler built in.
category: Interfaces
author: John Goerzen
exposed: True
exposed-modules:
    System.Log System.Log.Handler System.Log.Formatter
    System.Log.Handler.Simple System.Log.Handler.Syslog
    System.Log.Handler.Growl System.Log.Handler.Log4jXML
    System.Log.Logger
abi: 69499c85aa016a88a9673df6a34ea5ad
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hslogger-1.2.10
library-dirs: /usr/lib/ghc-8.0.1/site-local/hslogger-1.2.10
data-dir: /usr/share/arm-linux-ghc-8.0.1/hslogger-1.2.10
hs-libraries: HShslogger-1.2.10-P9bS995VPJKC7x0yPUAEo
depends:
    base-4.9.0.0 containers-0.5.7.1 directory-1.2.6.2
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    network-2.6.3.2-GMjPV5zpIjuBSljTanWiH
    old-locale-1.0.0.7-6glXNhHF891B41ZfuI8hU8 process-1.4.2.0
    time-1.6.0.1 unix-2.7.2.0
haddock-interfaces: /usr/share/doc/haskell-hslogger/html/hslogger.haddock
haddock-html: /usr/share/doc/haskell-hslogger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslogger-1.2.10-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hslogger.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hslogger
version: 1.2.10
id: hslogger-1.2.10-Li6ZV5C1ftGLPA71zPNMlf
key: hslogger-1.2.10-Li6ZV5C1ftGLPA71zPNMlf
license: BSD3
copyright: Copyright (c) 2004-2012 John Goerzen
maintainer: John Goerzen <jgoerzen@complete.org>
stability: Stable
homepage: http://software.complete.org/hslogger
synopsis: Versatile logging framework
description:
    hslogger is a logging framework for Haskell, roughly similar to
    Python'\''s logging module.
    .
    hslogger lets each log message have a priority and source be associated
    with it.  The programmer can then define global handlers that route
    or filter messages based on the priority and source.  hslogger also
    has a syslog handler built in.
category: Interfaces
author: John Goerzen
exposed: True
exposed-modules:
    System.Log System.Log.Handler System.Log.Formatter
    System.Log.Handler.Simple System.Log.Handler.Syslog
    System.Log.Handler.Growl System.Log.Handler.Log4jXML
    System.Log.Logger
abi: 95b3da18ea47aa26042f100a0ac1fd4a
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/hslogger-1.2.10
library-dirs: /usr/lib/ghc-8.0.2/site-local/hslogger-1.2.10
dynamic-library-dirs: /usr/lib/arm-linux-ghc-8.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.2/hslogger-1.2.10
hs-libraries: HShslogger-1.2.10-Li6ZV5C1ftGLPA71zPNMlf
depends:
    base-4.9.1.0 containers-0.5.7.1 directory-1.3.0.0
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    network-2.6.3.2-IsLM4TXcLoRI0fmmBYVyQz
    old-locale-1.0.0.7-KGBP1BSKxH5GCm0LnZP04j process-1.4.3.0
    time-1.6.0.1 unix-2.7.2.1
haddock-interfaces: /usr/share/doc/haskell-hslogger/html/hslogger.haddock
haddock-html: /usr/share/doc/haskell-hslogger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
